"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@oclif/test");
const fs = require("fs");
const YAML = require("js-yaml");
require("chai");
const config_1 = require("../common/config");
const test_utils_1 = require("../test-utils");
const COMMAND = 'load';
describe(COMMAND, () => {
    beforeEach(() => {
        fs.unlink(config_1.CONFIG_FILENAME, (err) => null);
    });
    afterEach(() => {
        fs.unlink(config_1.CONFIG_FILENAME, (err) => null);
    });
    test_1.test
        .stdout()
        .command([COMMAND, (0, test_utils_1.resourcePath)('openapi.yml')])
        .it('loads local definition definition file', (ctx) => {
        (0, test_1.expect)(ctx.stdout).to.contain('Loaded succesfully!');
    });
    test_1.test
        .nock('https://myapi.com', (api) => api.get('/openapi.json').reply(200, test_utils_1.testDefinition))
        .stdout()
        .command([COMMAND, 'https://myapi.com/openapi.json'])
        .it('loads remote definition file', (ctx) => {
        (0, test_1.expect)(ctx.stdout).to.contain('Loaded succesfully!');
    });
    test_1.test
        .stdout()
        .command([COMMAND, (0, test_utils_1.resourcePath)('openapi.yml')])
        .it(`creates a ${config_1.CONFIG_FILENAME} file`, (ctx) => {
        (0, test_1.expect)(fs.existsSync(config_1.CONFIG_FILENAME)).to.equal(true);
    });
    test_1.test
        .stdout()
        .command([COMMAND, (0, test_utils_1.resourcePath)('openapi.yml')])
        .it(`writes the definition path to the ${config_1.CONFIG_FILENAME} file`, (ctx) => {
        const config = YAML.load(fs.readFileSync(config_1.CONFIG_FILENAME));
        (0, test_1.expect)(config.definition).to.match(new RegExp('openapi.yml'));
    });
});
