"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const definition_1 = require("../common/definition");
const commonFlags = require("../common/flags");
class Read extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Read);
        const { dereference, validate, bundle, header, root, inject } = flags;
        const definition = (0, definition_1.resolveDefinition)(args.definition);
        if (!definition) {
            this.error('Please load a definition file', { exit: 1 });
        }
        let document;
        try {
            document = await (0, definition_1.parseDefinition)({
                definition,
                dereference,
                bundle,
                validate,
                inject,
                servers: flags.server,
                header,
                root,
            });
        }
        catch (err) {
            this.error(err, { exit: 1 });
        }
        const format = flags.format === 'json' || flags.json ? definition_1.OutputFormat.JSON : definition_1.OutputFormat.YAML;
        this.log((0, definition_1.stringifyDocument)({ document, format }));
    }
}
exports.default = Read;
Read.description = 'Read and manipulate definition files';
Read.examples = [
    '$ openapi read https://raw.githubusercontent.com/OAI/OpenAPI-Specification/master/examples/v3.0/petstore.yaml',
    `$ openapi read ./openapi.yml -f json > openapi.json`,
];
Read.flags = {
    ...commonFlags.help(),
    ...commonFlags.parseOpts(),
    ...commonFlags.outputFormat(),
};
Read.args = [
    {
        name: 'definition',
        description: 'input definition file',
    },
];
