"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveConfigFile = exports.getConfigValue = exports.CONFIG_FILENAME = void 0;
const os_1 = require("os");
const path = require("path");
const fs = require("fs");
const YAML = require("js-yaml");
exports.CONFIG_FILENAME = '.openapiconfig';
function getConfigValue(key, defaultValue) {
    const configFile = resolveConfigFile();
    if (configFile) {
        const config = YAML.load(fs.readFileSync(configFile));
        return config[key] || defaultValue;
    }
    return defaultValue;
}
exports.getConfigValue = getConfigValue;
// walk backwards from cwd until homedir and check if CONFIG_FILENAME exists
function resolveConfigFile() {
    let dir = path.resolve(process.cwd());
    while (dir.length >= (0, os_1.homedir)().length) {
        const checks = [
            path.join(dir, exports.CONFIG_FILENAME),
            path.join(dir, `${exports.CONFIG_FILENAME}.yml`),
            path.join(dir, `${exports.CONFIG_FILENAME}.yaml`),
        ];
        for (const check of checks) {
            if (fs.existsSync(check)) {
                return check;
            }
        }
        // walk backwards
        dir = path.resolve(path.join(dir, '..'));
    }
}
exports.resolveConfigFile = resolveConfigFile;
